@@ -10,11 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import io
 import logging
 import random
 
 import fixtures
-import six
 
 from openstackclient import shell
 from oslotest import base
@@ -93,8 +93,8 @@ class BaseTestCase(base.BaseTestCase):
 
         # Context manager here instead of setUp because we only want
         # output trapping around the run().
-        self.output = six.StringIO()
-        self.error = six.StringIO()
+        self.output = io.StringIO()
+        self.error = io.StringIO()
         stdout_fix = fixtures.MonkeyPatch('sys.stdout', self.output)
         stderr_fix = fixtures.MonkeyPatch('sys.stderr', self.error)
         with stdout_fix, stderr_fix:
@@ -159,7 +159,7 @@ class BaseTestCase(base.BaseTestCase):
             self.fail('Command does not fail as required (%s)' % signature)
         except CommandException as e:
             self.assertIn(
-                message, six.text_type(e),
+                message, str(e),
                 'Command "%s" fails with different message' % e.cmd)
 
     def resource_provider_create(self,
@@ -178,7 +178,7 @@ class BaseTestCase(base.BaseTestCase):
                 self.resource_provider_delete(res['uuid'])
             except CommandException as exc:
                 # may have already been deleted by a test case
-                err_message = six.text_type(exc).lower()
+                err_message = str(exc).lower()
                 if 'no resource provider' not in err_message:
                     raise
         self.addCleanup(cleanup)
@@ -255,7 +255,7 @@ class BaseTestCase(base.BaseTestCase):
                 self.openstack('resource provider allocation delete ' + uuid)
             except CommandException as exc:
                 # may have already been deleted by a test case
-                if 'not found' in six.text_type(exc).lower():
+                if 'not found' in str(exc).lower():
                     pass
         self.addCleanup(cleanup, consumer_uuid)
 
@@ -272,7 +272,7 @@ class BaseTestCase(base.BaseTestCase):
         if provider:
             # --provider can be specified multiple times so if we only get
             # a single string value convert to a list.
-            if isinstance(provider, six.string_types):
+            if isinstance(provider, str):
                 provider = [provider]
             cmd += ' ' + ' '.join(
                 '--provider %s' % rp_uuid for rp_uuid in provider)
@@ -286,7 +286,7 @@ class BaseTestCase(base.BaseTestCase):
                 self.openstack('resource provider allocation delete ' + uuid)
             except CommandException as exc:
                 # may have already been deleted by a test case
-                if 'not found' in six.text_type(exc).lower():
+                if 'not found' in str(exc).lower():
                     pass
         self.addCleanup(cleanup, consumer_uuid)
 
@@ -406,7 +406,7 @@ class BaseTestCase(base.BaseTestCase):
                 self.trait_delete(name)
             except CommandException as exc:
                 # may have already been deleted by a test case
-                err_message = six.text_type(exc).lower()
+                err_message = str(exc).lower()
                 if 'http 404' not in err_message:
                     raise
         self.addCleanup(cleanup)
@@ -444,7 +444,8 @@ class BaseTestCase(base.BaseTestCase):
                                       limit=None):
         cmd = 'allocation candidate list '
         for suffix, req_group in groups.items():
-            cmd += ' --group %s' % suffix
+            if suffix:
+                cmd += ' --group %s' % suffix
             cmd += self._allocation_candidates_option(**req_group)
             if limit is not None:
                 cmd += ' --limit %d' % limit
